From c6c26affcd545c5e0b2509e643e0566552d5ed98 Mon Sep 17 00:00:00 2001
From: Chao Long <longchao@uniontech.com>
Date: Thu, 3 Sep 2020 10:43:13 +0800
Subject: [PATCH] winex11.drv: Fix window min range limit.

Signed-off-by: Chao Long <longchao@uniontech.com>
---
 dlls/winex11.drv/window.c | 13 +++++++++++++
 1 file changed, 13 insertions(+)

diff --git a/dlls/winex11.drv/window.c b/dlls/winex11.drv/window.c
index 455957264b..4f1f9b96ef 100644
--- a/dlls/winex11.drv/window.c
+++ b/dlls/winex11.drv/window.c
@@ -721,6 +721,19 @@ static void set_size_hints( struct x11drv_win_data *data, DWORD style )
             size_hints->min_height = size_hints->max_height;
             size_hints->flags |= PMinSize | PMaxSize;
         }
+        else if (style & WS_THICKFRAME && GetWindowThreadProcessId( data->hwnd, NULL ) == GetCurrentThreadId())
+        {
+            MINMAXINFO info;
+            info.ptMinTrackSize.x = 0;
+            info.ptMinTrackSize.y = 0;
+            SendMessageW(data->hwnd, WM_GETMINMAXINFO, 0, (LPARAM)&info);
+            if (info.ptMinTrackSize.x!=0 && info.ptMinTrackSize.y!=0)
+            {
+                size_hints->min_width = info.ptMinTrackSize.x;
+                size_hints->min_height = info.ptMinTrackSize.y;
+                size_hints->flags |= PMinSize;
+            }
+        }
     }
     XSetWMNormalHints( data->display, data->whole_window, size_hints );
     XFree( size_hints );
-- 
2.20.1

